@@ -4,22 +4,18 @@
 */
 use ff::PrimeField;
 use group::{Group, GroupEncoding};
+use subtle::CtOption;
 
-pub fn bytes_to_field<F: PrimeField>(bytes: &[u8]) -> Option<F> {
+pub fn bytes_to_field<F: PrimeField>(bytes: &[u8]) -> CtOption<F> {
     let mut s_repr = F::Repr::default();
     s_repr.as_mut()[..bytes.len()].copy_from_slice(bytes);
 
     F::from_repr(s_repr)
 }
 
-pub fn bytes_to_group<G: Group + GroupEncoding>(bytes: &[u8]) -> Option<G> {
+pub fn bytes_to_group<G: Group + GroupEncoding>(bytes: &[u8]) -> CtOption<G> {
     let mut y_repr = <G as GroupEncoding>::Repr::default();
     y_repr.as_mut().copy_from_slice(bytes);
 
-    let y = G::from_bytes(&y_repr);
-    if y.is_some().unwrap_u8() == 1 {
-        Some(y.unwrap())
-    } else {
-        None
-    }
+    G::from_bytes(&y_repr)
 }
